From c3944a088f47ebe5a92dd303ade56da56db57902 Mon Sep 17 00:00:00 2001
From: Ulrike Uhlig <u@451f.org>
Date: Fri, 2 Nov 2018 19:12:38 +0100
Subject: [PATCH] Fix (user visible) strings and messages in documentation and
 tests.

---
 IkiWiki/Plugin/po.pm |  2 +-
 doc/plugins/po.mdwn  | 11 +++++++----
 t/po-integration.t   |  6 +++---
 3 files changed, 11 insertions(+), 8 deletions(-)

diff --git a/IkiWiki/Plugin/po.pm b/IkiWiki/Plugin/po.pm
index 48b059dfd..c2ceb1476 100644
--- a/IkiWiki/Plugin/po.pm
+++ b/IkiWiki/Plugin/po.pm
@@ -123,7 +123,7 @@ sub getsetup () {
 				'es',
 				'de'
 			],
-			description => 'slave languages, that should not visible in the webpage (maybe because they are not translated completly). format: languagecodes of the po_slave_languages',
+			description => 'existing slave languages that should not be visible on the website (e.g. they are not completely translated). format: ll|Langname',
 			safe => 1,
 			rebuild => 1,
 		},
diff --git a/doc/plugins/po.mdwn b/doc/plugins/po.mdwn
index ea510f498..32750dac4 100644
--- a/doc/plugins/po.mdwn
+++ b/doc/plugins/po.mdwn
@@ -59,10 +59,13 @@ languages, such as:
 	  - es|Español
 	  - de|Deutsch
 
-`po_disabled_languages` is used to disable languages in the webpage.
-It can be used to prepare the webpage for new languages, but to not show these
-languages to the end-user. the `po_disabled_languages` needs to be a list of
-languagecodes, that are listed in `po_slave_languages`. Such as:
+`po_disabled_languages` is used to disable languages on the website. It
+can be used to prepare new translations, while it will hide those from
+the end-user. More precisely, PO files for these languages are updated
+normally, however, HTML creation will be disabled and no reference to
+these translations will be visible on the website.
+`po_disabled_languages` needs to be a subset of `po_slave_languages`,
+such as:
 
 	po_disabled_languages:
 	  - es
diff --git a/t/po-integration.t b/t/po-integration.t
index be98923c4..3ca54b3dd 100755
--- a/t/po-integration.t
+++ b/t/po-integration.t
@@ -49,7 +49,7 @@ ok(-e "${dir}/in/index.de.po", "index.de.po exists");
 ok(-e "${dir}/in/index.es.po", "index.es.po exists");
 
 my $content = readfile("${dir}/in/index.pot");
-ok(index($content, 'msgid "This is a test line."')!= -1, 'pot file is uptodate');
+ok(index($content, 'msgid "This is a test line."')!= -1, 'pot file is up-to-date');
 
 $content = readfile("${dir}/in/index.de.po");
 ok(index($content, 'msgid "This is a test line."')!= -1, 'de.po was updated');
@@ -58,8 +58,8 @@ $content = readfile("${dir}/in/index.es.po");
 ok(index($content, 'msgid "This is a test line."')!= -1, 'es.po was updated');
 
 # run a second time, because the first time created the index.es.po
-# the result is that at first run index.en.po misses the link to index.es.html
-ok(! system(@command), 'run ikiwiki command (2nd run to get all links correct)');
+# the result is, that at first run index.en.po misses the link to index.es.html
+ok(! system(@command), 'run ikiwiki command (2nd run to create all links between translated files)');
 
 ok(-e "${dir}/out/index.en.html", "Spanish is enabled");
 ok(-e "${dir}/out/index.es.html", "English is enabled");
-- 
2.11.0

